# Check if the script is running with admin privileges
$isAdmin = ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole] "Administrator")

if (-not $isAdmin) {
    # If not running as admin, relaunch the script with admin privileges
    Start-Process -FilePath PowerShell.exe -ArgumentList "-File `"$PSCommandPath`"" -Verb RunAs
    exit
}

# Define paths
$WinTemp = "C:\Windows\Temp\*"
$Prefetch = "C:\Windows\Prefetch\*"
$UserTemp = "C:\Users\*\AppData\Local\Temp\*"

# Define system cleanup paths
$SystemCleanupPaths = @(
    "$env:windir\prefetch\*",
    "$env:windir\temp\*",
    "$env:SystemDrive\*.tmp",
    "$env:SystemDrive\*._mp",
    "$env:SystemDrive\*.log",
    "$env:SystemDrive\*.gid",
    "$env:SystemDrive\*.chk",
    "$env:SystemDrive\*.old",
    "$env:SystemDrive\recycled\*",
    "$env:windir\*.bak",
    "$env:windir\prefetch\*",
    "$env:windir\temp"
)

# Function to remove items with error handling
function Remove-ItemWithSilentContinue {
    param (
        [string]$Path
    )

    Remove-Item -Path $Path -Force -Recurse -ErrorAction SilentlyContinue
}

# Remove Temp Files
Write-Host "Removing Temp Files" -ForegroundColor Green

# Clean Windows Temp
Remove-ItemWithSilentContinue $WinTemp

# Clean Prefetch
Remove-ItemWithSilentContinue $Prefetch

# Clean User Temp
Get-ChildItem -Path $UserTemp -Recurse -Force -ErrorAction SilentlyContinue | ForEach-Object { Remove-ItemWithSilentContinue $_.FullName }

# Running Disk Cleanup Tool
Write-Host "Running the Windows Disk Cleanup Tool" -ForegroundColor White
Start-Process -FilePath "cleanmgr.exe" -ArgumentList "/sagerun:1" -Wait

# Empty the Recycle Bin
$RecycleBin = 'C:\$Recycle.Bin'
Get-ChildItem $RecycleBin -Force -Recurse -ErrorAction SilentlyContinue | Where-Object { $_.Extension -ne ".ini" } | ForEach-Object { Remove-ItemWithSilentContinue $_.FullName }
Write-Host "Recycle Bin is empty."

# Clear system junk files
Write-Host "Clearing system junk files, please wait..." -ForegroundColor White
$SystemCleanupPaths | ForEach-Object { Remove-ItemWithSilentContinue $_ }

# Cleanup task complete
Write-Host "Cleanup task complete! Continuing" -ForegroundColor Yellow

# Clear all event logs
Get-EventLog -List | ForEach-Object { Clear-EventLog $_.Log }

Write-Host "All event logs cleared successfully."